Name      : busybox
Version   : 0.52
Release   : 1
Group     : System/Utilities
Summary   : BusyBox is a tiny suite of Unix utilities in a multi-call binary.
Copyright : GPL
Packager  : Erik Andersen <andersen@lineo.com>
Conflicts : fileutils grep shellutils
Buildroot : /tmp/%{Name}-%{Version}
Source    : %{Name}-%{Version}.tar.gz
Source1	  : %{Name}-EBX-syslogd.init
Patch0    : %{Name}-EBX-fixes.patch

%Description
BusyBox combines tiny versions of many common UNIX utilities into a single 
small executable. It provides minimalist replacements for most of the 
utilities you usually find in fileutils, shellutils, findutils, textutils, 
grep, gzip, tar, etc. BusyBox provides a fairly complete POSIX environment 
for any small or embedded system. The utilities in BusyBox generally have 
fewer options than their full featured GNU cousins; however, the options 
that are included provide the expected functionality and behave very much 
like their GNU counterparts. 

BusyBox has been written with size-optimization and limited resources in 
mind. It is also extremely modular so you can easily include or exclude 
commands (or features) at compile time. This makes it easy to customize 
your embedded systems. To create a working system, just add /dev, a kernel, 
and a shell. For a really minimal system, you can even use the busybox 
shell (not Bourne compatible, but very small and quite usable), and the 
busybox vi editor. 

%Prep
%setup -q -n %{Name}-%{Version}
sed "s,/etc/init.d/rcS,/etc/rc.d/rcS," init.c > init.c.tmp; mv init.c.tmp init.c
%patch0 -p1

%Build

cat << 'EOD' > define.sh
#!/bin/sh
# define.sh - Used to create an include file full of #defines
#
# SYNOPSIS
#
#	define.sh POSIX_ME_HARDER
#
if [ $# -ge 1 ]; then
	while [ $# -ge 1 ]; do
		PREDEFVAR=""
		DEFVAR="$1"
		### Comments start with '---' ###
		if [ "`echo $1 | grep '^---'`" = "" ]; then
			### Embedix SDK variables are bracketed with "!!" ###
			if [ "`echo $1 | grep '^!!.*!!$'`" != "" ]; then
				DEFVAR="`echo $1 | sed -e s/^!!//g -e s/!!$//g`"
				if [ "$EMB_VARIANT_ROOT" != "" ]; then
					PREDEFVAR="// "
				fi
			fi
			if [ "${DEFVAR}" != "" ]; then
				echo "${PREDEFVAR}#define ${DEFVAR}"
			fi
		fi
		shift
	done
else
	echo "ERROR: Incorrect number of parameters: \"$*\""
	echo "USAGE: $0 VARIABLE"
fi
EOD
chmod 755 define.sh

BBCONFIG=Config.h

if [ ! -f ${BBCONFIG}.ORG ]; then
	mv ${BBCONFIG} ${BBCONFIG}.ORG
fi

echo "//" >> ${BBCONFIG}
echo "// Applications List" >> ${BBCONFIG}
echo "//" >> ${BBCONFIG}

./define.sh \
	!!BB_AR!! \
	!!BB_BASENAME!! \
	!!BB_CAT!! \
	!!BB_CHMOD!! \
	!!BB_CHOWN!! \
	!!BB_CHGRP!! \
	!!BB_CHROOT!! \
	!!BB_CHVT!! \
	!!BB_CLEAR!! \
	!!BB_CMDEDIT!! \
	!!BB_CMP!! \
	!!BB_CP!! \
	!!BB_MV!! \
	!!BB_CUT!! \
	!!BB_DATE!! \
	!!BB_DC!! \
	!!BB_DD!! \
	!!BB_DEALLOCVT!! \
	---!!BB_DEBUG_PRINT_SCAFFOLD!! \
	!!BB_DF!! \
	!!BB_DIRNAME!! \
	!!BB_DMESG!! \
	!!BB_DOS2UNIX!! \
	!!BB_DPKG_DEB!! \
	!!BB_DU!! \
	!!BB_DUMPKMAP!! \
	!!BB_DUTMP!! \
	!!BB_ECHO!! \
	!!BB_ENV!! \
	!!BB_EXPR!! \
	!!BB_FBSET!! \
	!!BB_FDFLUSH!! \
	!!BB_FIND!! \
	!!BB_FREE!! \
	!!BB_FREERAMDISK!! \
	!!BB_FSCK_MINIX!! \
	!!BB_GETOPT!! \
	!!BB_GREP!! \
	!!BB_GUNZIP!! \
	!!BB_GZIP!! \
	!!BB_HALT!! \
	!!BB_HEAD!! \
	!!BB_HOSTID!! \
	!!BB_HOSTNAME!! \
	!!BB_ID!! \
	!!BB_IFCONFIG!! \
	!!BB_INIT!! \
	---!!BB_INIT_SCRIPT!! \
	!!BB_INSMOD!! \
	!!BB_KILL!! \
	!!BB_LENGTH!! \
	---!!BB_LINUXRC!! \
	!!BB_LN!! \
	!!BB_LOADACM!! \
	!!BB_LOADFONT!! \
	!!BB_LOADKMAP!! \
	!!BB_LOGGER!! \
	!!BB_LOGNAME!! \
	!!BB_LS!! \
	!!BB_LSMOD!! \
	!!BB_MAKEDEVS!! \
	!!BB_MD5SUM!! \
	!!BB_MKDIR!! \
	!!BB_MKFIFO!! \
	!!BB_MKFS_MINIX!! \
	!!BB_MKNOD!! \
	!!BB_MKSWAP!! \
	!!BB_MKTEMP!! \
	!!BB_MORE!! \
	!!BB_MOUNT!! \
	!!BB_MT!! \
	!!BB_NC!! \
	!!BB_NFSMOUNT!! \
	!!BB_NSLOOKUP!! \
	!!BB_PING!! \
	!!BB_POWEROFF!! \
	!!BB_PRINTF!! \
	!!BB_PS!! \
	!!BB_PWD!! \
	!!BB_RDATE!! \
	!!BB_READLINK!! \
	!!BB_REBOOT!! \
	!!BB_RENICE!! \
	!!BB_RESET!! \
	!!BB_RM!! \
	!!BB_RMDIR!! \
	!!BB_RMMOD!! \
	!!BB_ROUTE!! \
	!!BB_RPM2CPIO!! \
	!!BB_SED!! \
	!!BB_SETKEYCODES!! \
	!!BB_SH!! \
	!!BB_SLEEP!! \
	!!BB_SORT!! \
	!!BB_STTY!! \
	!!BB_SWAPONOFF!! \
	!!BB_SYNC!! \
	!!BB_SYSLOGD!! \
	!!BB_TAIL!! \
	!!BB_TAR!! \
	!!BB_TEE!! \
	!!BB_TELNET!! \
	!!BB_TEST!! \
	!!BB_TOUCH!! \
	!!BB_TR!! \
	!!BB_TRUE_FALSE!! \
	!!BB_TTY!! \
	!!BB_UMOUNT!! \
	!!BB_UNAME!! \
	!!BB_UNIQ!! \
	!!BB_UNIX2DOS!! \
	---!!BB_UPDATE!! \
	!!BB_UPTIME!! \
	!!BB_USLEEP!! \
	!!BB_UUDECODE!! \
	!!BB_UUENCODE!! \
	!!BB_VI!! \
	!!BB_WATCHDOG!! \
	!!BB_WC!! \
	!!BB_WGET!! \
	!!BB_WHICH!! \
	!!BB_WHOAMI!! \
	!!BB_XARGS!! \
	!!BB_YES!! \
	>> ${BBCONFIG}

###
### Note:
###     BB_DEBUG_PRINT_SCAFFOLD is debug only
###		BB_LINUXRC is not available in the SDK
###     BB_UPDATE functionality is in 2.x kernels
###

echo "//" >> ${BBCONFIG}
echo "// End of Applications List" >> ${BBCONFIG}
echo "//" >> ${BBCONFIG}
echo "// Features List" >> ${BBCONFIG}
echo "//" >> ${BBCONFIG}

./define.sh \
	!!BB_FEATURE_AUTOWIDTH!! \
	!!BB_FEATURE_BUFFERS_GO_ON_STACK!! \
	---!!BB_FEATURE_CLEAN_UP!! \
	!!BB_FEATURE_EXTRA_QUIET!! \
	!!BB_FEATURE_FBSET_FANCY!! \
	!!BB_FEATURE_FBSET_READMODE!! \
	!!BB_FEATURE_GREP_CONTEXT!! \
	!!BB_FEATURE_HUMAN_READABLE!! \
	!!BB_FEATURE_IFCONFIG_MEMSTART_IOADDR_IRQ!! \
	!!BB_FEATURE_IFCONFIG_IFCONFIG_HW!! \
	---!!BB_FEATURE_INIT_CHROOT!! \
	---!!BB_FEATURE_INIT_COREDUMPS!! \
	!!BB_FEATURE_INSMOD_VERSION_CHECKING!! \
	---!!BB_FEATURE_INSTALLER!! \
	!!BB_FEATURE_KLOGD!! \
	---!!BB_FEATURE_LINUXRC!! \
	!!BB_FEATURE_LS_FILETYPES!! \
	!!BB_FEATURE_LS_FOLLOWLINKS!! \
	!!BB_FEATURE_LS_RECURSIVE!! \
	!!BB_FEATURE_LS_SORTFILES!! \
	!!BB_FEATURE_LS_TIMESTAMPS!! \
	!!BB_FEATURE_LS_USERNAME!! \
	!!BB_FEATURE_MINIX2!! \
	!!BB_FEATURE_MOUNT_FORCE!! \
	!!BB_FEATURE_MOUNT_LOOP!! \
	!!BB_FEATURE_NEW_MODULE_INTERFACE!! \
	!!BB_FEATURE_NFSMOUNT!! \
	---!!BB_FEATURE_OLD_MODULE_INTERFACE!! \
	!!BB_FEATURE_REMOTE_LOG!! \
	!!BB_FEATURE_RM_INTERACTIVE!! \
	!!BB_FEATURE_SH_APPLETS_ALWAYS_WIN!! \
	!!BB_FEATURE_SH_BACKTICKS!! \
	!!BB_FEATURE_COMMAND_EDITING!! \
	!!BB_FEATURE_SH_ENVIRONMENT!! \
	!!BB_FEATURE_SH_IF_EXPRESSIONS!! \
	!!BB_FEATURE_SH_STANDALONE_SHELL!! \
	!!BB_FEATURE_COMMAND_TAB_COMPLETION!! \
	!!BB_FEATURE_COMMAND_USERNAME_COMPLETION!! \
	!!BB_FEATURE_SIMPLE_PING!! \
	!!BB_FEATURE_SIMPLE_TAIL!! \
	!!BB_FEATURE_SORT_REVERSE!! \
	!!BB_FEATURE_TAR_CREATE!! \
	!!BB_FEATURE_TAR_EXCLUDE!! \
	!!BB_FEATURE_TAR_GZIP!! \
	!!BB_FEATURE_TRIVIAL_HELP!! \
	---!!BB_FEATURE_UTMP_SUPPORT!! \
	---!!BB_FEATURE_USERNAME_COMPLETION!! \
	---!!BB_FEATURE_USE_DEVPS_PATCH!! \
	!!BB_FEATURE_USE_INITTAB!! \
	!!BB_FEATURE_USE_PROCFS!! \
	!!BB_FEATURE_USE_TERMIOS!! \
	!!BB_FEATURE_VI_COLON!! \
	!!BB_FEATURE_VI_YANKMARK!! \
	!!BB_FEATURE_VI_SEARCH!! \
	!!BB_FEATURE_VI_USE_SIGNALS!! \
	!!BB_FEATURE_VI_DOT_CMD!! \
	!!BB_FEATURE_VI_READONLY!! \
	!!BB_FEATURE_VI_SETOPTS!! \
	!!BB_FEATURE_VI_SET!! \
	!!BB_FEATURE_VI_WIN_RESIZE!! \
	!!BB_FEATURE_WGET_STATUSBAR!! \
	>> ${BBCONFIG}

###
### Note:
###     BB_FEATURE_INIT_CHROOT is not available in the SDK
###     BB_FEATURE_INIT_COREDUMPS is debug only
###     BB_FEATURE_INSTALLER is not offered in the SDK yet
###     BB_FEATURE_LINUXRC is not available in the SDK
###     BB_FEATURE_OLD_MODULE_INTERFACE is not needed
###     BB_FEATURE_UTMP_SUPPORT is not used yet by busybox
###     BB_FEATURE_USERNAME_COMPLETION Fails to build
###     BB_FEATURE_USE_DEVPS_PATCH requires a kernel patch

echo "//" >> ${BBCONFIG}
echo "// End of Feature List" >> ${BBCONFIG}
echo "//" >> ${BBCONFIG}

POSITION=`grep -n "Nothing beyond this point should ever be touched by" \
	${BBCONFIG}.ORG | cut -d: -f1`
TOTALLINES=`cat ${BBCONFIG}.ORG | wc -l`
NUMLINES=$[${TOTALLINES}-${POSITION}+2]
tail -n ${NUMLINES} ${BBCONFIG}.ORG >> ${BBCONFIG}

echo "//" >> ${BBCONFIG}

make DOSTATIC=false DODEBUG=false

%Install
%{rmDESTDIR}
%{mkDESTDIR}
install -d $DESTDIR/bin
make PREFIX=$RPM_BUILD_ROOT install

mkdir -p $DESTDIR/etc/rc.d/init.d
cp -p %{SOURCE1} $DESTDIR/etc/rc.d/init.d/S05syslog
install -d $DESTDIR/var/{run,log}
touch $DESTDIR/var/run/utmp
touch $DESTDIR/var/log/wtmp

%Clean
%{rmDESTDIR}

%Files 
%defattr(-,root,root)
/

